# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-13 10:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_stripe', '0004_auto_20170613_0419'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stripecharge',
            name='stripe_charge_id',
            field=models.CharField(blank=True, db_index=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='stripecustomer',
            name='stripe_customer_id',
            field=models.CharField(db_index=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='stripesubscription',
            name='stripe_subscription_id',
            field=models.CharField(blank=True, db_index=True, max_length=255),
        ),
    ]
