# -*- coding: utf-8 -*-
__title__ = "Arabella Stripe"
__version__ = "0.2.11.1"
__author__ = "Jacek Ostanski"
__license__ = "MIT"
__copyright__ = "Copyright 2017 Arabella"

# Version synonym
VERSION = __version__
