# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-13 08:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_stripe', '0003_auto_20170608_1103'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='stripesubscription',
            name='application_fee_percent',
        ),
        migrations.AlterField(
            model_name='stripesubscriptionplan',
            name='currency',
            field=models.CharField(default='USD', help_text='3 letter ISO code, default USD, https://stripe.com/docs/api#create_plan-currency', max_length=3),
        ),
    ]
